Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func Email(v string) predicate.User
- func EmailContains(v string) predicate.User
- func EmailContainsFold(v string) predicate.User
- func EmailEQ(v string) predicate.User
- func EmailEqualFold(v string) predicate.User
- func EmailGT(v string) predicate.User
- func EmailGTE(v string) predicate.User
- func EmailHasPrefix(v string) predicate.User
- func EmailHasSuffix(v string) predicate.User
- func EmailIn(vs ...string) predicate.User
- func EmailLT(v string) predicate.User
- func EmailLTE(v string) predicate.User
- func EmailNEQ(v string) predicate.User
- func EmailNotIn(vs ...string) predicate.User
- func HasAIs() predicate.User
- func HasAIsWith(preds ...predicate.AI) predicate.User
- func HasModelNames() predicate.User
- func HasModelNamesWith(preds ...predicate.ModelName) predicate.User
- func HasOwner() predicate.User
- func HasOwnerWith(preds ...predicate.PasswordToken) predicate.User
- func HasPrices() predicate.User
- func HasPricesWith(preds ...predicate.Price) predicate.User
- func HasProducts() predicate.User
- func HasProductsWith(preds ...predicate.Product) predicate.User
- func ID(id int) predicate.User
- func IDEQ(id int) predicate.User
- func IDGT(id int) predicate.User
- func IDGTE(id int) predicate.User
- func IDIn(ids ...int) predicate.User
- func IDLT(id int) predicate.User
- func IDLTE(id int) predicate.User
- func IDNEQ(id int) predicate.User
- func IDNotIn(ids ...int) predicate.User
- func Name(v string) predicate.User
- func NameContains(v string) predicate.User
- func NameContainsFold(v string) predicate.User
- func NameEQ(v string) predicate.User
- func NameEqualFold(v string) predicate.User
- func NameGT(v string) predicate.User
- func NameGTE(v string) predicate.User
- func NameHasPrefix(v string) predicate.User
- func NameHasSuffix(v string) predicate.User
- func NameIn(vs ...string) predicate.User
- func NameLT(v string) predicate.User
- func NameLTE(v string) predicate.User
- func NameNEQ(v string) predicate.User
- func NameNotIn(vs ...string) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Password(v string) predicate.User
- func PasswordContains(v string) predicate.User
- func PasswordContainsFold(v string) predicate.User
- func PasswordEQ(v string) predicate.User
- func PasswordEqualFold(v string) predicate.User
- func PasswordGT(v string) predicate.User
- func PasswordGTE(v string) predicate.User
- func PasswordHasPrefix(v string) predicate.User
- func PasswordHasSuffix(v string) predicate.User
- func PasswordIn(vs ...string) predicate.User
- func PasswordLT(v string) predicate.User
- func PasswordLTE(v string) predicate.User
- func PasswordNEQ(v string) predicate.User
- func PasswordNotIn(vs ...string) predicate.User
- func RoleEQ(v Role) predicate.User
- func RoleIn(vs ...Role) predicate.User
- func RoleNEQ(v Role) predicate.User
- func RoleNotIn(vs ...Role) predicate.User
- func RoleValidator(r Role) error
- func ValidColumn(column string) bool
- func Verified(v bool) predicate.User
- func VerifiedEQ(v bool) predicate.User
- func VerifiedNEQ(v bool) predicate.User
- type OrderOption
- func ByAIs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAIsCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEmail(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByModelNames(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByModelNamesCount(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOwner(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOwnerCount(opts ...sql.OrderTermOption) OrderOption
- func ByPassword(opts ...sql.OrderTermOption) OrderOption
- func ByPrices(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByPricesCount(opts ...sql.OrderTermOption) OrderOption
- func ByProducts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByProductsCount(opts ...sql.OrderTermOption) OrderOption
- func ByRole(opts ...sql.OrderTermOption) OrderOption
- func ByVerified(opts ...sql.OrderTermOption) OrderOption
- type Role
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldEmail holds the string denoting the email field in the database. FieldEmail = "email" // FieldPassword holds the string denoting the password field in the database. FieldPassword = "password" // FieldVerified holds the string denoting the verified field in the database. FieldVerified = "verified" // FieldRole holds the string denoting the role field in the database. FieldRole = "role" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgePrices holds the string denoting the prices edge name in mutations. EdgePrices = "Prices" // EdgeProducts holds the string denoting the products edge name in mutations. EdgeProducts = "Products" // EdgeModelNames holds the string denoting the modelnames edge name in mutations. EdgeModelNames = "ModelNames" // EdgeAIs holds the string denoting the ais edge name in mutations. EdgeAIs = "AIs" // EdgeOwner holds the string denoting the owner edge name in mutations. EdgeOwner = "owner" // Table holds the table name of the user in the database. Table = "users" // PricesTable is the table that holds the Prices relation/edge. PricesTable = "prices" // PricesInverseTable is the table name for the Price entity. // It exists in this package in order to avoid circular dependency with the "price" package. PricesInverseTable = "prices" // PricesColumn is the table column denoting the Prices relation/edge. PricesColumn = "user_prices" // ProductsTable is the table that holds the Products relation/edge. ProductsTable = "products" // ProductsInverseTable is the table name for the Product entity. // It exists in this package in order to avoid circular dependency with the "product" package. ProductsInverseTable = "products" // ProductsColumn is the table column denoting the Products relation/edge. ProductsColumn = "user_products" // ModelNamesTable is the table that holds the ModelNames relation/edge. ModelNamesTable = "model_names" // ModelNamesInverseTable is the table name for the ModelName entity. // It exists in this package in order to avoid circular dependency with the "modelname" package. ModelNamesInverseTable = "model_names" // ModelNamesColumn is the table column denoting the ModelNames relation/edge. ModelNamesColumn = "user_model_names" // AIsTable is the table that holds the AIs relation/edge. AIsTable = "ais" // AIsInverseTable is the table name for the AI entity. // It exists in this package in order to avoid circular dependency with the "ai" package. AIsInverseTable = "ais" // AIsColumn is the table column denoting the AIs relation/edge. AIsColumn = "user_ais" // OwnerTable is the table that holds the owner relation/edge. OwnerTable = "password_tokens" // OwnerInverseTable is the table name for the PasswordToken entity. // It exists in this package in order to avoid circular dependency with the "passwordtoken" package. OwnerInverseTable = "password_tokens" // OwnerColumn is the table column denoting the owner relation/edge. OwnerColumn = "password_token_user" )
const DefaultRole = RoleUser
RoleUser is the default value of the Role enum.
Variables ¶
var ( Hooks [1]ent.Hook // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // EmailValidator is a validator for the "email" field. It is called by the builders before save. EmailValidator func(string) error // PasswordValidator is a validator for the "password" field. It is called by the builders before save. PasswordValidator func(string) error // DefaultVerified holds the default value on creation for the "verified" field. DefaultVerified bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/Arash-Afshar/pagoda-tailwindcss/ent/runtime"
var Columns = []string{ FieldID, FieldName, FieldEmail, FieldPassword, FieldVerified, FieldRole, FieldCreatedAt, }
Columns holds all SQL columns for user fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Email ¶
Email applies equality check predicate on the "email" field. It's identical to EmailEQ.
func EmailContains ¶
EmailContains applies the Contains predicate on the "email" field.
func EmailContainsFold ¶
EmailContainsFold applies the ContainsFold predicate on the "email" field.
func EmailEqualFold ¶
EmailEqualFold applies the EqualFold predicate on the "email" field.
func EmailHasPrefix ¶
EmailHasPrefix applies the HasPrefix predicate on the "email" field.
func EmailHasSuffix ¶
EmailHasSuffix applies the HasSuffix predicate on the "email" field.
func EmailNotIn ¶
EmailNotIn applies the NotIn predicate on the "email" field.
func HasAIsWith ¶
HasAIsWith applies the HasEdge predicate on the "AIs" edge with a given conditions (other predicates).
func HasModelNames ¶
HasModelNames applies the HasEdge predicate on the "ModelNames" edge.
func HasModelNamesWith ¶
HasModelNamesWith applies the HasEdge predicate on the "ModelNames" edge with a given conditions (other predicates).
func HasOwnerWith ¶
func HasOwnerWith(preds ...predicate.PasswordToken) predicate.User
HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).
func HasPricesWith ¶
HasPricesWith applies the HasEdge predicate on the "Prices" edge with a given conditions (other predicates).
func HasProducts ¶
HasProducts applies the HasEdge predicate on the "Products" edge.
func HasProductsWith ¶
HasProductsWith applies the HasEdge predicate on the "Products" edge with a given conditions (other predicates).
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Password ¶
Password applies equality check predicate on the "password" field. It's identical to PasswordEQ.
func PasswordContains ¶
PasswordContains applies the Contains predicate on the "password" field.
func PasswordContainsFold ¶
PasswordContainsFold applies the ContainsFold predicate on the "password" field.
func PasswordEQ ¶
PasswordEQ applies the EQ predicate on the "password" field.
func PasswordEqualFold ¶
PasswordEqualFold applies the EqualFold predicate on the "password" field.
func PasswordGT ¶
PasswordGT applies the GT predicate on the "password" field.
func PasswordGTE ¶
PasswordGTE applies the GTE predicate on the "password" field.
func PasswordHasPrefix ¶
PasswordHasPrefix applies the HasPrefix predicate on the "password" field.
func PasswordHasSuffix ¶
PasswordHasSuffix applies the HasSuffix predicate on the "password" field.
func PasswordIn ¶
PasswordIn applies the In predicate on the "password" field.
func PasswordLT ¶
PasswordLT applies the LT predicate on the "password" field.
func PasswordLTE ¶
PasswordLTE applies the LTE predicate on the "password" field.
func PasswordNEQ ¶
PasswordNEQ applies the NEQ predicate on the "password" field.
func PasswordNotIn ¶
PasswordNotIn applies the NotIn predicate on the "password" field.
func RoleValidator ¶
RoleValidator is a validator for the "role" field enum values. It is called by the builders before save.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Verified ¶
Verified applies equality check predicate on the "verified" field. It's identical to VerifiedEQ.
func VerifiedEQ ¶
VerifiedEQ applies the EQ predicate on the "verified" field.
func VerifiedNEQ ¶
VerifiedNEQ applies the NEQ predicate on the "verified" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByAIs ¶
func ByAIs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAIs orders the results by AIs terms.
func ByAIsCount ¶
func ByAIsCount(opts ...sql.OrderTermOption) OrderOption
ByAIsCount orders the results by AIs count.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEmail ¶
func ByEmail(opts ...sql.OrderTermOption) OrderOption
ByEmail orders the results by the email field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByModelNames ¶
func ByModelNames(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByModelNames orders the results by ModelNames terms.
func ByModelNamesCount ¶
func ByModelNamesCount(opts ...sql.OrderTermOption) OrderOption
ByModelNamesCount orders the results by ModelNames count.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOwner ¶
func ByOwner(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOwner orders the results by owner terms.
func ByOwnerCount ¶
func ByOwnerCount(opts ...sql.OrderTermOption) OrderOption
ByOwnerCount orders the results by owner count.
func ByPassword ¶
func ByPassword(opts ...sql.OrderTermOption) OrderOption
ByPassword orders the results by the password field.
func ByPrices ¶
func ByPrices(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByPrices orders the results by Prices terms.
func ByPricesCount ¶
func ByPricesCount(opts ...sql.OrderTermOption) OrderOption
ByPricesCount orders the results by Prices count.
func ByProducts ¶
func ByProducts(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByProducts orders the results by Products terms.
func ByProductsCount ¶
func ByProductsCount(opts ...sql.OrderTermOption) OrderOption
ByProductsCount orders the results by Products count.
func ByRole ¶
func ByRole(opts ...sql.OrderTermOption) OrderOption
ByRole orders the results by the role field.
func ByVerified ¶
func ByVerified(opts ...sql.OrderTermOption) OrderOption
ByVerified orders the results by the verified field.